<main>
  <div class="consent-container">
    {% include "enterprise/_data_sharing_top_paragraph.html" %}
    {% include "enterprise/_data_sharing_user_input.html" %}
    {% include "enterprise/_data_sharing_policy_paragraph.html" %}
  </div>
  {% include "enterprise/_data_sharing_decline_modal.html" %}
</main>
