# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-12-05 17:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0056_enterprisecustomerreportingconfiguration_pgp_encryption_key'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomerreportingconfiguration',
            name='enterprise_customer_catalogs',
            field=models.ManyToManyField(to='enterprise.EnterpriseCustomerCatalog', verbose_name='Enterprise Customer Catalogs'),
        ),
    ]
