# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-09-10 18:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0052_create_unique_slugs'),
    ]

    operations = [
        migrations.AddField(
            model_name='pendingenrollment',
            name='cohort_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
